@@ -17,11 +17,7 @@
 import functools
 import inspect
 import logging
-import warnings
-
-import six
-from six.moves import urllib
-
+import urllib
 
 logger = logging.getLogger(__name__)
 
@@ -45,7 +41,7 @@ def positional(max_positional_args):
     This decorator makes it easy to support Python 3 style keyword-only
     parameters. For example, in Python 3 it is possible to write::
 
-        def fn(pos1, *, kwonly1=None, kwonly1=None):
+        def fn(pos1, *, kwonly1=None, kwonly2=None):
             ...
 
     All named parameters after ``*`` must be a keyword::
@@ -97,7 +93,7 @@ def positional(max_positional_args):
 
     Args:
         max_positional_arguments: Maximum number of positional arguments. All
-                                  parameters after the this index must be
+                                  parameters after this index must be
                                   keyword only.
 
     Returns:
@@ -105,7 +101,7 @@ def positional(max_positional_args):
         from being used as positional parameters.
 
     Raises:
-        TypeError: if a key-word only argument is provided as a positional
+        TypeError: if a keyword-only argument is provided as a positional
                    parameter, but only if
                    _helpers.positional_parameters_enforcement is set to
                    POSITIONAL_EXCEPTION.
@@ -135,7 +131,7 @@ def positional(max_positional_args):
 
         return positional_wrapper
 
-    if isinstance(max_positional_args, six.integer_types):
+    if isinstance(max_positional_args, int):
         return positional_decorator
     else:
         args, _, _, defaults = inspect.getargspec(max_positional_args)
@@ -156,7 +152,7 @@ def parse_unique_urlencoded(content):
     """
     urlencoded_params = urllib.parse.parse_qs(content)
     params = {}
-    for key, value in six.iteritems(urlencoded_params):
+    for key, value in urlencoded_params.items():
         if len(value) != 1:
             msg = "URL-encoded content contains a repeated value:" "%s -> %s" % (
                 key,
